ChiantiPy.core.tests package — ChiantiPy 0.15.0 documentation

# ChiantiPy.core.tests package

## Submodules

## ChiantiPy.core.tests.test_Continuum module

Tests for the continuum class

`ChiantiPy.core.tests.test_Continuum.` `test_free_bound_array`()

`ChiantiPy.core.tests.test_Continuum.` `test_free_bound_no_info`()

`ChiantiPy.core.tests.test_Continuum.` `test_free_bound_scalar`()

`ChiantiPy.core.tests.test_Continuum.` `test_free_free_array`()

`ChiantiPy.core.tests.test_Continuum.` `test_free_free_scalar`()

`ChiantiPy.core.tests.test_Continuum.` `test_temperature`()

## ChiantiPy.core.tests.test_Ion module

Tests for the ion class.

`ChiantiPy.core.tests.test_Ion.` `test_abundance`()

`ChiantiPy.core.tests.test_Ion.` `test_chianti_files`()

`ChiantiPy.core.tests.test_Ion.` `test_temperature_density`()

## ChiantiPy.core.tests.test_Ioneq module

Tests for ioneq class

`ChiantiPy.core.tests.test_Ioneq.` `test_calculate_ioneq`()

`ChiantiPy.core.tests.test_Ioneq.` `test_el_input`()

`ChiantiPy.core.tests.test_Ioneq.` `test_el_z_inputs_same`()

`ChiantiPy.core.tests.test_Ioneq.` `test_load_ioneq`()

`ChiantiPy.core.tests.test_Ioneq.` `test_load_ioneq_alternate_file`()

`ChiantiPy.core.tests.test_Ioneq.` `test_z_input`()

## ChiantiPy.core.tests.test_Spectrum module

Tests for the spectrum and bunch classes

`ChiantiPy.core.tests.test_Spectrum.` `test_bunch`()

`ChiantiPy.core.tests.test_Spectrum.` `test_spectrum_array`()

`ChiantiPy.core.tests.test_Spectrum.` `test_spectrum_scalar`()

## Module contents